==> IceWarpServer-9.1.0_RHEL5.tar.gz: html/webmail/server/inc/inputstream.php <==
<?php
require_once "parsexml.php";
/**
 * @brief	Class than represents input stream.
 * @output  ->GetString
 *		  ->GetArray
 * @date	1.6.2005
 */
class InputStream
{
		private $sInputXML;  // Private string buffer
		private $aInputXML;  // Private array buffer
		private $oInputXML;  // Private DOM object buffer
	  /**
		* @brief: Constructor
		*/
		public function __construct() {
			static $sBuffer;
			static $aBuffer;
			//Opens an file from request
			if (!isset($sBuffer)){
				$handle = fopen("php://input", "rb");
				while (!feof($handle)) $sBuffer .= fread($handle, 4096);
				$sBuffer = trim($sBuffer);
				@fclose($handle);

        global $sInput;
        $sInput = $sBuffer;
        
				// Errors
				if (!$sBuffer)
					throw new Exc("No XML input",'no_xml_input'); //High
				

      	if (!$oBuffer = XML::openFromString($sBuffer))
					throw new Exc("Corrupted XML input",'corrupted_input');//High

				if (!($aBuffer = ParseXML::XML2Array($sBuffer)))
					throw new Exc("Corrupted XML input");//High*/
			}
			//Store the data
			$this->oInputXML = $oBuffer;
			$this->sInputXML = $sBuffer;
			$this->aInputXML = $aBuffer;
		}
	  /**
		* @brief: checks if there are no double-dots in tested paths
		* @return: String of input XML
		*/
		public function getString(){
			return $this->sInputXML;
		}
	  /**
		* @brief: checks if there are no double-dots in tested paths
		* @return: Parsed array of input XML
		*/
		public function getArray(){
			return $this->aInputXML;
		}
			/**
		* @brief: Returns an XML DOM object
		* @return: DOM for input XML
		*/
		public function getDOM(){
			return $this->oInputXML;
		}
}
?>

==> IceWarpServer-9.4.1_RHEL5.tar.gz: html/webmail/server/inc/inputstream.php <==
<?php
require_once "parsexml.php";
/**
 * @brief	Class than represents input stream.
 * @output  ->GetString
 *		  ->GetArray
 * @date	1.6.2005
 */
class InputStream
{
		private $sInputXML;  // Private string buffer
		private $aInputXML;  // Private array buffer
		private $oInputXML;  // Private DOM object buffer
	  /**
		* @brief: Constructor
		*/
		public function __construct() {
			static $sBuffer;
			static $aBuffer;
			//Opens an file from request
			if (!isset($sBuffer)){
			    $sBuffer = trim(file_get_contents("php://input"));
			    /*
				$handle = fopen("php://input", "rb");
				while (!feof($handle)) $sBuffer .= fread($handle, 65536);
				$sBuffer = trim($sBuffer);
				@fclose($handle);
				*/
				//Convert incoming request to UTF-8 (Firefox3 FIX)
				preg_match("#charset=(.*)#i",$_SERVER['CONTENT_TYPE'],$matches);
				$charset = trim($matches[1]);
				if(stripos($_SERVER['HTTP_USER_AGENT'],'Firefox/3.0.4')!==false){
					$charset = 'iso-8859-1';
				}
				if($charset && substr(strtolower($charset),0,5)!='utf-8'){
			  	$sBuffer = iconv($charset,'UTF-8//IGNORE',$sBuffer);
			  }
        global $sInput;
        $sInput = $sBuffer;
        
				// Errors
				if (!$sBuffer)
					throw new Exc('inputstream_no_xml_input'); //High
				

      	if (!$oBuffer = XML::openFromString($sBuffer))
					throw new Exc('inputstream_corrupted_input',$sBuffer);//High

				if (!($aBuffer = ParseXML::XML2Array($sBuffer)))
					throw new Exc('inputstream_corrupted_input',$sBuffer);//High*/
			}
			//Store the data
			$this->oInputXML = $oBuffer;
			$this->sInputXML = $sBuffer;
			$this->aInputXML = $aBuffer;
		}
	  /**
		* @brief: checks if there are no double-dots in tested paths
		* @return: String of input XML
		*/
		public function getString(){
			return $this->sInputXML;
		}
	  /**
		* @brief: checks if there are no double-dots in tested paths
		* @return: Parsed array of input XML
		*/
		public function getArray(){
			return $this->aInputXML;
		}
			/**
		* @brief: Returns an XML DOM object
		* @return: DOM for input XML
		*/
		public function getDOM(){
			return $this->oInputXML;
		}
}
?>
